package com.huiju.foyo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.foyo.common.BaseController;
import com.huiju.foyo.common.ConstantFoyo;
import com.huiju.foyo.common.ResponseBean;
import com.huiju.foyo.model.TaCaseType;
import com.huiju.foyo.service.ITaCaseTypeService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.Arrays;
import java.util.List;

/**
 * <p>
    * 案列类型表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-08-21
 */
@RestController
@RequestMapping("/")
public class TaCaseTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaCaseTypeController.class);

    @Autowired
    public ITaCaseTypeService iTaCaseTypeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/caseType/{type}/list",method= RequestMethod.GET)
    public ResponseBean taCaseTypeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       @PathVariable String type){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaCaseType> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaCaseType> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("type", type);
            queryWrapper.orderByDesc("create_time");

            IPage<TaCaseType> result = iTaCaseTypeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseTypeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taCaseType 实体对象
     * @return
     */
    @RequestMapping(value="/admin/caseType/add",method= RequestMethod.POST)
    public ResponseBean taCaseTypeAdd(@RequestBody TaCaseType taCaseType){
        ResponseBean responseBean = new ResponseBean();
        try {
            taCaseType.setCreateBy(ConstantFoyo.USER_ADMIN);
            taCaseType.setCreateTime(LocalDateTime.now());
            if (iTaCaseTypeService.save(taCaseType)){
                responseBean.addSuccess(taCaseType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseTypeAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id批量删除对象
     */
    @ResponseBody
    @RequestMapping(value="/admin/caseType/delete", method= RequestMethod.DELETE)
    public ResponseBean taCaseTypeDelete(@RequestBody String[] ids){
        ResponseBean responseBean = new ResponseBean();
        try {
            List<String> idList = Arrays.asList(ids);
            if(iTaCaseTypeService.removeByIds(idList)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taCaseType 实体对象
     * @return
     */
    @RequestMapping(value="/taCaseType/{id}",method= RequestMethod.PUT)
    public ResponseBean taCaseTypeUpdate(@PathVariable Integer id,
                                        @RequestBody TaCaseType taCaseType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaCaseTypeService.updateById(taCaseType)){
                responseBean.addSuccess(taCaseType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseTypeUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taCaseType/{id}",method= RequestMethod.GET)
    public ResponseBean taCaseTypeGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaCaseTypeService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    /**
     * 查询列表
     */
    @RequestMapping(value="/admin/caseTypes",method= RequestMethod.GET)
    public ResponseBean getCaseTypeList(){
        ResponseBean responseBean = new ResponseBean();
        try {
            QueryWrapper<TaCaseType> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_time");
            responseBean.addSuccess(iTaCaseTypeService.list(queryWrapper));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseTypeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/pc/caseType/list",method= RequestMethod.GET)
    public ResponseBean pcCaseTypeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
            IPage<TaCaseType> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaCaseType> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("sort");
            queryWrapper.orderByDesc("create_time");
            
            IPage<TaCaseType> result = iTaCaseTypeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseTypeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
