package com.huiju.foyo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.foyo.common.BaseController;
import com.huiju.foyo.common.ResponseBean;
import com.huiju.foyo.model.TaServiceLabel;
import com.huiju.foyo.service.ITaServiceLabelService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 服务标签表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-08-21
 */
@RestController
@RequestMapping("/")
public class TaServiceLabelController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaServiceLabelController.class);

    @Autowired
    public ITaServiceLabelService iTaServiceLabelService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taServiceLabel",method= RequestMethod.GET)
    public ResponseBean taServiceLabelList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaServiceLabel> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaServiceLabel> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_time");

            IPage<TaServiceLabel> result = iTaServiceLabelService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taServiceLabelList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taServiceLabel 实体对象
     * @return
     */
    @RequestMapping(value="/taServiceLabel",method= RequestMethod.POST)
    public ResponseBean taServiceLabelAdd(@RequestBody TaServiceLabel taServiceLabel){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaServiceLabelService.save(taServiceLabel)){
                responseBean.addSuccess(taServiceLabel);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taServiceLabelAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taServiceLabel/{id}", method= RequestMethod.DELETE)
    public ResponseBean taServiceLabelDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaServiceLabelService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taServiceLabelDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taServiceLabel 实体对象
     * @return
     */
    @RequestMapping(value="/taServiceLabel/{id}",method= RequestMethod.PUT)
    public ResponseBean taServiceLabelUpdate(@PathVariable Integer id,
                                        @RequestBody TaServiceLabel taServiceLabel){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaServiceLabelService.updateById(taServiceLabel)){
                responseBean.addSuccess(taServiceLabel);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taServiceLabelUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taServiceLabel/{id}",method= RequestMethod.GET)
    public ResponseBean taServiceLabelGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaServiceLabelService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taServiceLabelDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
